@@ -60,6 +60,20 @@ class s2py():
                 "referer": "",
             }
 
+    def postProfileComment(self, user, content,parentid="",cid=""):
+        data = {
+            "commentee_id": cid,
+            "content": content,
+            "parent_id": parentid,
+        }
+        data = json.dumps(data)
+        self.headers['referer'] = "https://scratch.mit.edu/users/"+user
+        return requests.post(
+            "https://scratch.mit.edu/site-api/comments/user/" + user + "/add/",
+            headers=self.headers,
+            data=data,
+        )
+    
     def decode(self, text):
         return encoder.decode(text)
     
